@@ -18,8 +18,7 @@ CREATE_LOGGER(SimulationFlow);
 void SimulationFlow::singleAction()
 {
 	Scene* scene = Omega::instance().getScene().get();
-	if (!scene)
-		throw logic_error("SimulationFlow::singleAction: no Scene object?!");
+	if (!scene) throw logic_error("SimulationFlow::singleAction: no Scene object?!");
 	if (scene->subStepping) {
 		LOG_INFO("Sub-stepping disabled when running simulation continuously.");
 		scene->subStepping = false;
