@@ -19,14 +19,12 @@ class Body;
 class TimeStepper : public GlobalEngine {
 public:
 	virtual void computeTimeStep(Scene*) { throw; };
-	virtual bool isActivated() { return (active && (scene->iter % timeStepUpdateInterval == 0)); };
-	virtual void action() { computeTimeStep(scene); };
+	bool         isActivated() override { return (active && (scene->iter % timeStepUpdateInterval == 0)); };
+	void         action() override { computeTimeStep(scene); };
 	void         setActive(bool a, int nb = -1)
 	{
 		active = a;
-		if (nb > 0) {
-			timeStepUpdateInterval = (unsigned int)nb;
-		}
+		if (nb > 0) { timeStepUpdateInterval = (unsigned int)nb; }
 	}
 
 	// clang-format off
