@@ -9,15 +9,15 @@ void crashHandler(int sig)
 {
 	switch (sig) {
 		case SIGABRT:
-		case SIGSEGV:
+		case SIGSEGV: {
 			signal(SIGSEGV, SIG_DFL);
 			signal(SIGABRT, SIG_DFL); // prevent loops - default handlers
 			std::cerr << "SIGSEGV/SIGABRT handler called; gdb batch file is `" << yade::Omega::instance().gdbCrashBatch << "'" << std::endl;
 			int ret = std::system((std::string("gdb -x ") + yade::Omega::instance().gdbCrashBatch).c_str());
-			if (ret != 0)
-				std::cerr << "unable to execute gdb" << std::endl;
+			if (ret != 0) std::cerr << "unable to execute gdb" << std::endl;
 			raise(sig); // reemit signal after exiting gdb
-			break;
+		} break;
+		default: break;
 	}
 }
 #endif
