@@ -112,10 +112,14 @@ namespace math {
 /*************************************************************************/
 /************************* long double 80 bits  **************************/
 /*************************************************************************/
-#elif YADE_REAL_BIT <= 80
+#elif ((YADE_REAL_BIT <= 80) or defined(YADE_NON_386_LONG_DOUBLE))
 namespace yade {
 namespace math {
+#ifdef YADE_NON_386_LONG_DOUBLE // other architectures: arm64, ppc64el, s390x
+	using UnderlyingReal = long double;
+#else
 	using UnderlyingReal = boost::float_fast80_t;
+#endif
 }
 }
 
@@ -123,6 +127,9 @@ namespace math {
 /*************************  float128 128 bits   **************************/
 /*************************************************************************/
 #elif YADE_REAL_BIT <= 128
+#ifdef YADE_FLOAT128_UNAVAILABLE
+#error "float128 is not supported, possible reasons: clang compiler https://github.com/boostorg/math/issues/181 or architecture arm64, mips64el, ppc64el, s390x"
+#endif
 #include <boost/multiprecision/float128.hpp>
 namespace yade {
 namespace math {
@@ -146,7 +153,11 @@ namespace math {
 /************************* boost::cpp_bin_float **************************/
 /*************************************************************************/
 #elif defined(YADE_REAL_BBFLOAT)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Warray-bounds"
 #include <boost/multiprecision/cpp_bin_float.hpp>
+#pragma GCC diagnostic pop
 namespace yade {
 namespace math {
 	template <unsigned int DecimalPlaces> using UnderlyingRealBackend = boost::multiprecision::cpp_bin_float<DecimalPlaces>;
@@ -175,7 +186,7 @@ namespace math {
 /*************************     declare Real     **************************/
 /*************************************************************************/
 
-#if (YADE_REAL_BIT <= 80) and (YADE_REAL_BIT > 64)
+#if (((YADE_REAL_BIT <= 80) and (YADE_REAL_BIT > 64)) or defined(YADE_NON_386_LONG_DOUBLE))
 // `long double` needs special consideration to workaround boost::python losing 3 digits precision
 #include "ThinComplexWrapper.hpp"
 #include "ThinRealWrapper.hpp"
