@@ -48,7 +48,11 @@ struct ComplexHP {
 #include <boost/multiprecision/mpc.hpp>
 #endif
 #else
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Warray-bounds"
 #include <boost/multiprecision/cpp_bin_float.hpp>
+#pragma GCC diagnostic pop
 #if (BOOST_VERSION >= 107100)
 #include <boost/multiprecision/cpp_complex.hpp>
 #endif
@@ -76,7 +80,7 @@ namespace math { // store info that ThinRealWrapper is not used.
 #endif
 // clang currently does not support float128   https://github.com/boostorg/math/issues/181
 // another similar include is in ThinRealWrapper.hpp, all other checks if we have float128 should be #ifdef BOOST_MP_FLOAT128_HPP or yade::math::isFloat128<T>
-#if (((((YADE_REAL_BIT <= 64) and (not defined(YADE_DISABLE_REAL_MULTI_HP)))) or (YADE_REAL_BIT == 128)) and (not defined(__clang__)))
+#if (((((YADE_REAL_BIT <= 64) and (not defined(YADE_DISABLE_REAL_MULTI_HP)))) or (YADE_REAL_BIT == 128)) and (not defined(YADE_FLOAT128_UNAVAILABLE)))
 #include <boost/multiprecision/float128.hpp>
 #if (BOOST_VERSION >= 107100)
 #include <boost/multiprecision/complex128.hpp>
@@ -122,7 +126,7 @@ namespace math {
 #endif
 #if ((BOOST_VERSION >= 107100) and defined(YADE_COMPLEX_MP))
 // ENABLE_COMPLEX_MP=ON : The ComplexHP type is extended with (1) complex128 and (2) mpc_complex_backend<…> and (3) complex_adaptor<cpp_bin_float<…>>
-#if (((((YADE_REAL_BIT <= 64) and (not defined(YADE_DISABLE_REAL_MULTI_HP)))) or (YADE_REAL_BIT == 128)) and (not defined(__clang__)))
+#if (((((YADE_REAL_BIT <= 64) and (not defined(YADE_DISABLE_REAL_MULTI_HP)))) or (YADE_REAL_BIT == 128)) and (not defined(YADE_FLOAT128_UNAVAILABLE)))
 		template <> struct MakeComplex<boost::multiprecision::float128> {
 			using type = boost::multiprecision::complex128;
 		};
@@ -180,7 +184,7 @@ namespace math {
 #else // clang does not support float128   https://github.com/boostorg/math/issues/181
 	using RealHPLadder = boost::mpl::vector<Real>; // when float128 is not available the RealHPLadder does not include it.
 #endif
-#elif YADE_REAL_BIT <= 80
+#elif ((YADE_REAL_BIT <= 80) or defined(YADE_NON_386_LONG_DOUBLE))
 	// Real == long double
 	// Here it might become interesting in few years when templatized versions of doubling-* and quadding-* of types are implemented in boost::multiprecision.
 	// Then it will be high speed, high precision. Because long double although not standarized is pretty fast, and then if it's doubled or quadded it might be good and fast.
