@@ -7,10 +7,16 @@
 
 #pragma once
 
-#ifndef YADE_OPENGL
-#error "This build doesn't support openGL. Therefore, this header must not be used."
+#if ((not defined(YADE_OPENGL)) or (not defined(YADE_QT5)))
+#error "This build doesn't support OpenGL. Therefore, this header must not be used."
 #endif
 
+// This is included first.
+#include <QtGui/qopengl.h>
+// We have to make sure to use the OpenGL version shipped with QT, otherwise we may end up with strange conflicts and crashes. Se we don't #include <GL/gl.h>
+#include <GL/glu.h>
+#include <GL/glut.h>
+
 #include <lib/base/Math.hpp>
 #include <type_traits>
 
@@ -18,9 +24,6 @@
 template <typename T> struct dontCallThis : std::false_type {
 };
 
-#include <GL/gl.h>
-#include <GL/glut.h>
-
 namespace forCtags {
 struct OpenGLWrapper {
 }; // for ctags
@@ -374,8 +377,7 @@ template <typename Type> inline void glOneFace(Type& t, unsigned int a, unsigned
 	yade::Vector3r       n      = (t->v[b] - t->v[a]).cross(t->v[c] - t->v[a]);
 	n.normalize();
 	const yade::Vector3r faceCenter = (t->v[a] + t->v[b] + t->v[c]) / 3.;
-	if ((faceCenter - center).dot(n) < 0)
-		n = -n;
+	if ((faceCenter - center).dot(n) < 0) n = -n;
 	glNormal3v(n);
 	glVertex3v(t->v[a]);
 	glVertex3v(t->v[b]);
