@@ -1,8 +1,6 @@
 /*************************************************************************
-*  Copyright (C) 2004 by Olivier Galizzi                                 *
-*  olivier.galizzi@imag.fr                                               *
-*  Copyright (C) 2004 by Janek Kozicki                                   *
-*  cosurgi@berlios.de                                                    *
+*  2004      Olivier Galizzi                                             *
+*  2004-2021 Janek Kozicki                                               *
 *                                                                        *
 *  This program is free software; it is licensed under the terms of the  *
 *  GNU General Public License v2 or later. See file LICENSE for details. *
@@ -17,6 +15,8 @@
 #include <lib/factory/Factorable.hpp>
 #include <lib/pyutil/doc_opts.hpp>
 #include <lib/pyutil/raw_constructor.hpp>
+// Include it as the last one: for high precision types, make sure that def_readonly(…) does not return internal reference.
+#include <lib/serialization/PyClassCustom.hpp>
 
 namespace yade {
 
@@ -113,8 +113,7 @@ template <class C, typename T, T C::*A> void make_setter_postLoad(C& instance, c
 		std::string docStr(_ATTR_DOC(attr));                                                                                                           \
 		docStr += " :yattrflags:`" + boost::lexical_cast<string>(_ATTR_FLG(attr)) + "` ";                                                              \
                                                                                                                                                                \
-		if (_ref && !_ro && !_post)                                                                                                                    \
-			_classObj.def_readwrite(_ATTR_NAM_STR(attr), &thisClass::_ATTR_NAM(attr), docStr.c_str());                                             \
+		if (_ref && !_ro && !_post) _classObj.def_readwrite(_ATTR_NAM_STR(attr), &thisClass::_ATTR_NAM(attr), docStr.c_str());                         \
 		else if (_ref && !_ro && _post)                                                                                                                \
 			_classObj.add_property(                                                                                                                \
 			        _ATTR_NAM_STR(attr),                                                                                                           \
@@ -162,8 +161,7 @@ template <class C, typename T, T C::*A> void make_setter_postLoad(C& instance, c
 	                                 "|ydeprecated| alias for :yref:`" BOOST_PP_STRINGIZE(_DEPREC_NEWNAME(z)) "<" BOOST_PP_STRINGIZE(thisClass) "." BOOST_PP_STRINGIZE(             \
 	                _DEPREC_NEWNAME(z)) ">` (" _DEPREC_COMMENT(z) ")")
 #define _PYHASKEY_ATTR_DEPREC(x, thisClass, z)                                                                                                                 \
-	if (key == BOOST_PP_STRINGIZE(_DEPREC_OLDNAME(z)))                                                                                                     \
-		return true;
+	if (key == BOOST_PP_STRINGIZE(_DEPREC_OLDNAME(z))) return true;
 
 /* accessors functions ussing warning */
 #define _ACCESS_DEPREC(x, thisClass, z) /*getter*/                                                                                                             \
@@ -180,8 +178,7 @@ template <class C, typename T, T C::*A> void make_setter_postLoad(C& instance, c
 
 // loop bodies for attribute access
 #define _PYGET_ATTR(x, y, z)                                                                                                                                   \
-	if (key == _ATTR_NAM_STR(z))                                                                                                                           \
-		return ::boost::python::object(_ATTR_NAM(z));
+	if (key == _ATTR_NAM_STR(z)) return ::boost::python::object(_ATTR_NAM(z));
 #if (YADE_REAL_BIT <= 80)
 #define _PYSET_ATTR(x, y, z)                                                                                                                                   \
 	if (key == _ATTR_NAM_STR(z)) {                                                                                                                         \
@@ -197,15 +194,11 @@ template <class C, typename T, T C::*A> void make_setter_postLoad(C& instance, c
 #endif
 #define _PYKEYS_ATTR(x, y, z) ret.append(_ATTR_NAM_STR(z));
 #define _PYHASKEY_ATTR(x, y, z)                                                                                                                                \
-	if (key == _ATTR_NAM_STR(z))                                                                                                                           \
-		return true;
+	if (key == _ATTR_NAM_STR(z)) return true;
 #define _PYDICT_ATTR(x, y, z)                                                                                                                                  \
-	if (!(_ATTR_FLG(z) & yade::Attr::hidden))                                                                                                              \
-		ret[_ATTR_NAM_STR(z)] = ::boost::python::object(_ATTR_NAM(z));
+	if (!(_ATTR_FLG(z) & yade::Attr::hidden)) ret[_ATTR_NAM_STR(z)] = ::boost::python::object(_ATTR_NAM(z));
 #define _REGISTER_BOOST_ATTRIBUTES_REPEAT(x, y, z)                                                                                                             \
-	if ((_ATTR_FLG(z) & yade::Attr::noSave) == 0) {                                                                                                        \
-		ar& BOOST_SERIALIZATION_NVP(_ATTR_NAM(z));                                                                                                     \
-	}
+	if ((_ATTR_FLG(z) & yade::Attr::noSave) == 0) { ar& BOOST_SERIALIZATION_NVP(_ATTR_NAM(z)); }
 #define _REGISTER_BOOST_ATTRIBUTES(baseClass, attrs)                                                                                                           \
 	friend class boost::serialization::access;                                                                                                             \
                                                                                                                                                                \
@@ -214,26 +207,24 @@ private:
 	{                                                                                                                                                      \
 		ar& BOOST_SERIALIZATION_BASE_OBJECT_NVP(baseClass);                                                                                            \
 		/* with ADL, either the generic (empty) version above or baseClass::preLoad etc will be called (compile-time resolution) */                    \
-		if (ArchiveT::is_loading::value)                                                                                                               \
-			preLoad(*this);                                                                                                                        \
+		if (ArchiveT::is_loading::value) preLoad(*this);                                                                                               \
 		else                                                                                                                                           \
 			preSave(*this);                                                                                                                        \
 		BOOST_PP_SEQ_FOR_EACH(_REGISTER_BOOST_ATTRIBUTES_REPEAT, ~, attrs)                                                                             \
-		if (ArchiveT::is_loading::value)                                                                                                               \
-			postLoad(*this);                                                                                                                       \
+		if (ArchiveT::is_loading::value) postLoad(*this);                                                                                              \
 		else                                                                                                                                           \
 			postSave(*this);                                                                                                                       \
 	}
 
 #define _REGISTER_ATTRIBUTES_DEPREC(thisClass, baseClass, attrs, deprec)                                                                                                                                                                                                   \
-	_REGISTER_BOOST_ATTRIBUTES(baseClass, attrs) public : void pySetAttr(const std::string& key, const ::boost::python::object& value)                                                                                                                                 \
+	_REGISTER_BOOST_ATTRIBUTES(baseClass, attrs) public : void pySetAttr(const std::string& key, const ::boost::python::object& value) override                                                                                                                        \
 	{                                                                                                                                                                                                                                                                  \
 		BOOST_PP_SEQ_FOR_EACH(_PYSET_ATTR, ~, attrs);                                                                                                                                                                                                              \
 		BOOST_PP_SEQ_FOR_EACH(_PYSET_ATTR_DEPREC, thisClass, deprec);                                                                                                                                                                                              \
 		baseClass::pySetAttr(key, value);                                                                                                                                                                                                                          \
 	}                                                                                                                                                                                                                                                                  \
 	/* list all attributes (except deprecated ones); could return ::boost::python::set instead*/ /* ::boost::python::list pyKeys() const {  ::boost::python::list ret; BOOST_PP_SEQ_FOR_EACH(_PYKEYS_ATTR,~,attrs); ret.extend(baseClass::pyKeys()); return ret; }  */ \
-	/* return dictionary of all acttributes and values; deprecated attributes omitted */ ::boost::python::dict pyDict() const                                                                                                                                          \
+	/* return dictionary of all acttributes and values; deprecated attributes omitted */ ::boost::python::dict pyDict() const override                                                                                                                                 \
 	{                                                                                                                                                                                                                                                                  \
 		::boost::python::dict ret;                                                                                                                                                                                                                                 \
 		BOOST_PP_SEQ_FOR_EACH(_PYDICT_ATTR, ~, attrs);                                                                                                                                                                                                             \
@@ -241,7 +232,7 @@ private:
 		ret.update(baseClass::pyDict());                                                                                                                                                                                                                           \
 		return ret;                                                                                                                                                                                                                                                \
 	}                                                                                                                                                                                                                                                                  \
-	virtual void callPostLoad(void)                                                                                                                                                                                                                                    \
+	void callPostLoad(void) override                                                                                                                                                                                                                                   \
 	{                                                                                                                                                                                                                                                                  \
 		baseClass::callPostLoad();                                                                                                                                                                                                                                 \
 		postLoad(*this);                                                                                                                                                                                                                                           \
@@ -296,12 +287,12 @@ private:
 	REGISTER_CLASS_AND_BASE(thisClass, baseClass)                                                                                                          \
 	/* accessors for deprecated attributes, with warnings */ BOOST_PP_SEQ_FOR_EACH(                                                                        \
 	        _ACCESS_DEPREC, thisClass, deprec) /* python class registration */ virtual void                                                                \
-	pyRegisterClass(::boost::python::object _scope)                                                                                                        \
+	pyRegisterClass(::boost::python::object _scope) override                                                                                               \
 	{                                                                                                                                                      \
 		checkPyClassRegistersItself(#thisClass);                                                                                                       \
 		::boost::python::scope thisScope(_scope);                                                                                                      \
 		YADE_SET_DOCSTRING_OPTS;                                                                                                                       \
-		::boost::python::class_<thisClass, shared_ptr<thisClass>, ::boost::python::bases<baseClass>, boost::noncopyable> _classObj(                    \
+		::boost::python::PyClassCustom<thisClass, shared_ptr<thisClass>, ::boost::python::bases<baseClass>, boost::noncopyable> _classObj(             \
 		        #thisClass, docString);                                                                                                                \
 		_classObj.def("__init__", ::boost::python::raw_constructor(Serializable_ctor_kwAttrs<thisClass>));                                             \
 		BOOST_PP_SEQ_FOR_EACH(_PYATTR_DEF, thisClass, attrs);                                                                                          \
@@ -336,13 +327,13 @@ private:
 
 
 #define _STATCLASS_PY_REGISTER_CLASS(thisClass, baseClass, docString, attrs)                                                                                   \
-	virtual void pyRegisterClass(::boost::python::object _scope)                                                                                           \
+	void pyRegisterClass(::boost::python::object _scope) override                                                                                          \
 	{                                                                                                                                                      \
 		checkPyClassRegistersItself(#thisClass);                                                                                                       \
 		initSetStaticAttributesValue();                                                                                                                \
 		::boost::python::scope thisScope(_scope);                                                                                                      \
 		YADE_SET_DOCSTRING_OPTS;                                                                                                                       \
-		::boost::python::class_<thisClass, shared_ptr<thisClass>, ::boost::python::bases<baseClass>, boost::noncopyable> _classObj(                    \
+		::boost::python::PyClassCustom<thisClass, shared_ptr<thisClass>, ::boost::python::bases<baseClass>, boost::noncopyable> _classObj(             \
 		        #thisClass, docString "\n\n" BOOST_PP_SEQ_FOR_EACH(_STATATTR_MAKE_DOC, thisClass, attrs));                                             \
 		_classObj.def("__init__", ::boost::python::raw_constructor(Serializable_ctor_kwAttrs<thisClass>));                                             \
 		BOOST_PP_SEQ_FOR_EACH(_STATATTR_PY, thisClass, attrs);                                                                                         \
@@ -353,12 +344,12 @@ private:
 	REGISTER_CLASS_AND_BASE(pyClassName, baseClass)                                                                                                        \
 	/* accessors for deprecated attributes, with warnings */ BOOST_PP_SEQ_FOR_EACH(                                                                        \
 	        _ACCESS_DEPREC, thisClass, deprec) /* python class registration */ virtual void                                                                \
-	pyRegisterClass(::boost::python::object _scope)                                                                                                        \
+	pyRegisterClass(::boost::python::object _scope) override                                                                                               \
 	{                                                                                                                                                      \
 		checkPyClassRegistersItself(#pyClassName);                                                                                                     \
 		::boost::python::scope thisScope(_scope);                                                                                                      \
 		YADE_SET_DOCSTRING_OPTS;                                                                                                                       \
-		::boost::python::class_<thisClass, shared_ptr<thisClass>, ::boost::python::bases<baseClass>, boost::noncopyable> _classObj(                    \
+		::boost::python::PyClassCustom<thisClass, shared_ptr<thisClass>, ::boost::python::bases<baseClass>, boost::noncopyable> _classObj(             \
 		        #pyClassName, docString);                                                                                                              \
 		_classObj.def("__init__", ::boost::python::raw_constructor(Serializable_ctor_kwAttrs<thisClass>));                                             \
 		BOOST_PP_SEQ_FOR_EACH(_PYATTR_DEF, thisClass, attrs);                                                                                          \
