@@ -8,9 +8,9 @@
 
 #pragma once
 
-#include <pkg/common/Aabb.hpp>
+#include <core/Aabb.hpp>
+#include <core/Dispatching.hpp>
 #include <pkg/common/Box.hpp>
-#include <pkg/common/Dispatching.hpp>
 #include <pkg/common/Facet.hpp>
 #include <pkg/common/Sphere.hpp>
 
@@ -18,7 +18,7 @@ namespace yade { // Cannot have #include directive inside.
 
 class Bo1_Sphere_Aabb : public BoundFunctor {
 public:
-	void go(const shared_ptr<Shape>& cm, shared_ptr<Bound>& bv, const Se3r&, const Body*);
+	void go(const shared_ptr<Shape>& cm, shared_ptr<Bound>& bv, const Se3r&, const Body*) override;
 	FUNCTOR1D(Sphere);
 	// clang-format off
 	YADE_CLASS_BASE_DOC_ATTRS(Bo1_Sphere_Aabb,BoundFunctor,"Functor creating :yref:`Aabb` from :yref:`Sphere`.",
@@ -40,7 +40,7 @@ REGISTER_SERIALIZABLE(Bo1_Sphere_Aabb);
 
 class Bo1_Facet_Aabb : public BoundFunctor {
 public:
-	void go(const shared_ptr<Shape>& cm, shared_ptr<Bound>& bv, const Se3r& se3, const Body*);
+	void go(const shared_ptr<Shape>& cm, shared_ptr<Bound>& bv, const Se3r& se3, const Body*) override;
 	FUNCTOR1D(Facet);
 	// clang-format off
 	YADE_CLASS_BASE_DOC(Bo1_Facet_Aabb,BoundFunctor,"Creates/updates an :yref:`Aabb` of a :yref:`Facet`.");
@@ -60,7 +60,7 @@ REGISTER_SERIALIZABLE(Bo1_Facet_Aabb);
 class Box;
 class Bo1_Box_Aabb : public BoundFunctor {
 public:
-	void go(const shared_ptr<Shape>& cm, shared_ptr<Bound>& bv, const Se3r& se3, const Body*);
+	void go(const shared_ptr<Shape>& cm, shared_ptr<Bound>& bv, const Se3r& se3, const Body*) override;
 	FUNCTOR1D(Box);
 	// clang-format off
 	YADE_CLASS_BASE_DOC(Bo1_Box_Aabb,BoundFunctor,"Create/update an :yref:`Aabb` of a :yref:`Box`.");
