@@ -9,7 +9,7 @@ namespace yade { // Cannot have #include directive inside.
 #ifdef YADE_OPENGL
 class Gl1_PFacet : public GlShapeFunctor {
 public:
-	virtual void go(const shared_ptr<Shape>&, const shared_ptr<State>&, bool, const GLViewInfo&);
+	void go(const shared_ptr<Shape>&, const shared_ptr<State>&, bool, const GLViewInfo&) override;
 	RENDERS(PFacet);
 	// clang-format off
 	YADE_CLASS_BASE_DOC_STATICATTRS(Gl1_PFacet,GlShapeFunctor,"Renders :yref:`Facet` object",
