@@ -100,14 +100,12 @@ class InsertionSortCollider : public Collider {
 		bool operator<(const Bounds& b) const
 		{
 			/* handle special case of zero-width bodies, which could otherwise get min/max swapped in the unstable std::sort */
-			if (id == b.id && coord == b.coord)
-				return flags.isMin;
+			if (id == b.id && coord == b.coord) return flags.isMin;
 			return coord < b.coord;
 		}
 		bool operator>(const Bounds& b) const
 		{
-			if (id == b.id && coord == b.coord)
-				return !flags.isMin;
+			if (id == b.id && coord == b.coord) return !flags.isMin;
 			return coord > b.coord;
 		}
 	};
@@ -138,8 +136,7 @@ class InsertionSortCollider : public Collider {
 		// normalize given index to the right range (wraps around)
 		size_t norm(long i) const
 		{
-			if (i < 0)
-				i += size();
+			if (i < 0) i += size();
 			assert(i >= 0);
 			size_t ret = i % size();
 			assert(ret < size());
@@ -165,8 +162,7 @@ class InsertionSortCollider : public Collider {
 		void reserve(size_t n) { vec.reserve(n); }
 		void resize(size_t n)
 		{
-			if (n > vec.size())
-				LOG_ERROR("not supposed to increase size - shrink only");
+			if (n > vec.size()) LOG_ERROR("not supposed to increase size - shrink only");
 			vec.resize(n, Bounds(0, 0, true));
 		}
 		void push_back(const Bounds& bb) { vec.push_back(bb); }
@@ -175,6 +171,9 @@ class InsertionSortCollider : public Collider {
 		void                                sort() { std::sort(vec.begin(), vec.end()); }
 		std::vector<Bounds>::const_iterator cbegin() const { return vec.cbegin(); }
 		std::vector<Bounds>::const_iterator cend() const { return vec.cend(); }
+		std::vector<Bounds>::iterator       begin() { return vec.begin(); }
+		std::vector<Bounds>::iterator       end() { return vec.end(); }
+		std::vector<Bounds>::iterator       insert(std::vector<Bounds>::iterator pos, Bounds& bb) { return vec.insert(pos, bb); }
 
 	private:
 		std::vector<Bounds> vec;
@@ -196,6 +195,7 @@ private:
   	    http://en.wikipedia.org/wiki/Insertion_sort has the algorithm and other details
 	*/
 	void insertionSort(VecBounds& v, InteractionContainer*, Scene*, bool doCollide = true);
+	void findOverlaps(VecBounds& V);
 #ifdef YADE_OPENMP
 	void insertionSortParallel(VecBounds& v, InteractionContainer*, Scene*, bool doCollide = true);
 #endif
@@ -223,26 +223,25 @@ public:
 	//! Predicate called from loop within InteractionContainer::erasePending
 	bool shouldBeErased(Body::id_t id1, Body::id_t id2, Scene* rb) const
 	{
-		if (!periodic)
-			return !spatialOverlap(id1, id2);
+		if (!periodic) return !spatialOverlap(id1, id2);
 		else {
 			Vector3i periods;
 			return !spatialOverlapPeri(id1, id2, rb, periods);
 		}
 	}
-	virtual bool isActivated();
+	bool isActivated() override;
 
 	// force reinitialization at next run
-	virtual void invalidatePersistentData()
+	void invalidatePersistentData() override
 	{
 		for (int i = 0; i < 3; i++) {
 			BB[i].clear();
 		}
 	}
 
-	vector<Body::id_t> probeBoundingVolume(const Bound&);
+	vector<Body::id_t> probeBoundingVolume(const Bound&) override;
 
-	virtual void action();
+	void action() override;
 	// clang-format off
 	YADE_CLASS_BASE_DOC_ATTRS_CTOR_PY(InsertionSortCollider,Collider,"\
 		Collider with O(n log(n)) complexity, using :yref:`Aabb` for bounds.\
@@ -277,8 +276,8 @@ public:
 		((int,numReinit,0,Attr::readonly,"Cummulative number of bound array re-initialization."))
 		((int,numAction,0,,"Cummulative number of collision detection."))
 		((bool,doSort,false,,"Do forced resorting of interactions."))
-		((bool,shortListsInitialized,false,Attr::noSave,"wether or not shortList algorithm is initialized, when true bodies are inserted incrementaly."))
 		((bool,keepListsShort,false,,"if true remove bounds of non-existent or unbounded bodies from the lists |yupdate|; turned true automatically in MPI mode and if bodies are erased with :yref:`BodyContainer.enableRedirection`=True."))
+		((bool,smartInsertErase,false,,"Use an algorithm optimized for heavy insert/delete (avoid initSort) - experimental."))
 		((shared_ptr<NewtonIntegrator>, newton,shared_ptr<NewtonIntegrator>(),,"reference to active :yref:`Newton integrator<NewtonIntegrator>`. |yupdate|"))
 		, /* ctor */
 			#ifdef ISC_TIMING
