@@ -7,9 +7,9 @@
 *************************************************************************/
 #pragma once
 
+#include <core/Dispatching.hpp>
 #include <core/Scene.hpp>
 #include <pkg/common/Collider.hpp>
-#include <pkg/common/Dispatching.hpp>
 #include <pkg/common/PeriodicEngines.hpp>
 #include <string>
 #include <vector>
@@ -20,7 +20,7 @@ namespace yade { // Cannot have #include directive inside.
 class ResetRandomPosition : public PeriodicEngine {
 public:
 	/// @brief Create one sphere per call.
-	virtual void action();
+	void action() override;
 
 private:
 	/// @brief Pointer to Collider.
