@@ -1,5 +1,5 @@
 // © 2009 Václav Šmilauer <eudoxos@arcig.cz>
-#include <pkg/common/Aabb.hpp>
+#include <core/Aabb.hpp>
 #include <pkg/common/Wall.hpp>
 
 #ifdef YADE_OPENGL
@@ -19,12 +19,9 @@ Wall::~Wall() { } // vtable
 void Bo1_Wall_Aabb::go(const shared_ptr<Shape>& cm, shared_ptr<Bound>& bv, const Se3r& se3, const Body* /*b*/)
 {
 	Wall* wall = static_cast<Wall*>(cm.get());
-	if (!bv) {
-		bv = shared_ptr<Bound>(new Aabb);
-	}
+	if (!bv) { bv = shared_ptr<Bound>(new Aabb); }
 	Aabb* aabb = static_cast<Aabb*>(bv.get());
-	if (scene->isPeriodic && scene->cell->hasShear())
-		throw logic_error(__FILE__ "Walls not supported in sheared cell.");
+	if (scene->isPeriodic && scene->cell->hasShear()) throw logic_error(__FILE__ "Walls not supported in sheared cell.");
 	const Real& inf       = std::numeric_limits<Real>::infinity();
 	aabb->min             = Vector3r(-inf, -inf, -inf);
 	aabb->min[wall->axis] = se3.position[wall->axis];
