@@ -21,7 +21,7 @@ private:
 	shared_ptr<TriaxialCompressionEngine> triaxialCompressionEngine;
 
 public:
-	virtual void action();
+	void action() override;
 
 	// clang-format off
 	YADE_CLASS_BASE_DOC_ATTRS_CTOR(CapillaryStressRecorder,Recorder,"Records information from capillary meniscii on samples submitted to triaxial compressions. Classical sign convention (tension positiv) is used for capillary stresses. -> New formalism needs to be tested!!!",,initRun=true;);
