@@ -8,6 +8,7 @@
 
 #pragma once
 #include <lib/base/Math.hpp>
+#include <core/Aabb.hpp>
 #include <core/Dispatcher.hpp>
 #include <core/Functor.hpp>
 #include <core/IGeom.hpp>
@@ -16,7 +17,6 @@
 #include <core/Scene.hpp>
 #include <core/Shape.hpp>
 #include <core/State.hpp>
-#include <pkg/common/Aabb.hpp>
 #include <pkg/fem/DeformableElement.hpp>
 
 
@@ -41,7 +41,7 @@ REGISTER_SERIALIZABLE(InternalForceFunctor);
 class InternalForceDispatcher : public Dispatcher2D<
                                         /* functor type*/ InternalForceFunctor> {
 public:
-	virtual void action();
+	void action() override;
 	//	void explicitAction(const shared_ptr<DeformableElement>& deformableelement,const Body* bdy);
 
 	//virtual bool isActivated(){ return activated; }
