@@ -7,16 +7,16 @@
 #pragma GCC diagnostic ignored "-Wpragmas"
 #pragma GCC diagnostic ignored "-Wsuggest-override"
 #pragma GCC diagnostic ignored "-Wcast-function-type"
+#include <cstdlib>
 #include <mpi.h>
 #pragma GCC diagnostic pop
 
 #include <pkg/common/Box.hpp>
 #include <pkg/common/Facet.hpp>
 #include <pkg/common/Grid.hpp>
+#include <pkg/common/InsertionSortCollider.hpp>
 #include <pkg/common/Sphere.hpp>
 
-#include <iostream>
-
 namespace yade { // Cannot have #include directive inside.
 
 CREATE_LOGGER(FoamCoupling);
@@ -29,42 +29,83 @@ YADE_PLUGIN((Bo1_FluidDomainBbox_Aabb));
 void Bo1_FluidDomainBbox_Aabb::go(const shared_ptr<Shape>& cm, shared_ptr<Bound>& bv, const Se3r&, const Body*)
 {
 	FluidDomainBbox* domain = static_cast<FluidDomainBbox*>(cm.get());
-	if (!bv) { bv = shared_ptr<Bound>(new Aabb); }
+	if (!bv) {
+		bv = shared_ptr<Bound>(new Aabb);
+	}
 	Aabb* aabb = static_cast<Aabb*>(bv.get());
-
-	aabb->min = scene->isPeriodic ? scene->cell->wrapPt(domain->minBound) : domain->minBound;
-	aabb->max = scene->isPeriodic ? scene->cell->wrapPt(domain->maxBound) : domain->maxBound;
+	aabb->min  = scene->isPeriodic ? scene->cell->wrapPt(domain->minBound) : domain->minBound;
+	aabb->max  = scene->isPeriodic ? scene->cell->wrapPt(domain->maxBound) : domain->maxBound;
 	return;
 }
 
-
-/******serial version *****/
-
-void FoamCoupling::getRank()
+void FoamCoupling::SetFoamSolver(const std::string& solverName, unsigned numProcs)
 {
-	if (couplingModeParallel) {
-		scene = Omega::instance().getScene().get();
-		MPI_Comm_rank(selfComm(), &localRank);
-		MPI_Comm_size(selfComm(), &localCommSize);
+	foamSolverName = solverName;
+	numFoamProcs   = numProcs;
+}
 
-		MPI_Comm_rank(MPI_COMM_WORLD, &worldRank);
-		MPI_Comm_size(MPI_COMM_WORLD, &worldCommSize);
-		commSizeSet = true;
-		stride      = localCommSize;
-		commSzdff   = abs(localCommSize - worldCommSize);
-	} else {
+void FoamCoupling::StartFoamSolver()
+{
+	assert(initDone == false && "Coupling has been initialized!");
+	assert(!foamSolverName.empty() && "OpenFOAM solver has not been set.");
+	if (foamSolverName.empty()) LOG_ERROR("OpenFoam environment not found. Is environment variable WM_PROJECT_DIR defined?")
+	scene = Omega::instance().getScene().get();
+	// local rank and sizes
+	MPI_Comm_rank(selfComm(), &localRank);
+	MPI_Comm_size(selfComm(), &localCommSize);
+
+	// spawn the openfoam process with the requested solver.
+	// char *solverName = const_cast<char*>(foamSolverName.data());
+
+	if (localRank == 0) std::cout << "Starting OpenFOAM solver --> " << foamSolverName << "  with number of processes = " << numFoamProcs << "\n";
+	std::string par = "-parallel";
+
+	char** argVs = new char*[2];
+	argVs[0]     = const_cast<char*>(par.c_str());
+	argVs[1]     = NULL;
+
+	MPI_Comm_spawn(foamSolverName.data(), argVs, numFoamProcs, MPI_INFO_NULL, 0, MPI_COMM_WORLD, &FOAMCOMM, MPI_ERRCODES_IGNORE);
+	if (localRank == 0)
+		std::cout << "OpenFOAM sovler " << foamSolverName << "  started"
+		          << "\n";
+
+	// merge the openfoam child communicator for communications.
+	MPI_Intercomm_merge(FOAMCOMM, 0, &INTRACOMM); // all openfoam communications are now done on INTRACOMM.
+	std::cout << "comms merged" << std::endl;
+
+	MPI_Comm_size(INTRACOMM, &worldCommSize);
+
+	MPI_Comm_remote_size(FOAMCOMM, &foamCommSize);
+
+	// sanity check of the FOAMCOMM and numFoamProcs
+	if (localRank == 0) {
+		assert(foamCommSize == numFoamProcs && "possible MPI error, difference in FoamCommunicator size and number of OpenFOAM processes.");
+		assert(worldCommSize == foamCommSize + localCommSize && "invalid intracommunicator size");
+	}
+
+	//
+	if (localCommSize == 1) serialYade = true;
+	stride = localCommSize;
+	// initiate the communication with OF, get the mesh bounding boxes from openfoam.
+	getFluidDomainBbox();
+	// FIXME!
+	if (serialYade) {
+		// use the collider once to get interactions between the bodies in coupling and the fluid domain boxes.
+		// This is only needed in the serial case. In the parallel case, the collider is expliclty called
+		// to create interactions between the SubDomains, bodies, and Fluid domains...
+		// Better way to do this? or is there a way to 'set' interactions between specified pair of bodies?
+		// Is this the right way to do?
 		MPI_Comm_rank(MPI_COMM_WORLD, &rank);
 		MPI_Comm_size(MPI_COMM_WORLD, &commSize);
-		commSizeSet = true;
+		// const auto &collider = YADE_PTR_CAST<InsertionSortCollider>(scene->engineByName("InsertionSortCollider"));
+		// collider->action();
 	}
+	std::cout << "got the fluid boxes and init done" << std::endl;
+	initDone = true;
 }
 
-void FoamCoupling::setNumParticles(int np)
-{
-	getRank();
-	numParticles = np;
-	initDone     = true;
-}
+
+void FoamCoupling::setNumParticles(int np) { numParticles = np; }
 
 void FoamCoupling::setIdList(const std::vector<int>& alist)
 {
@@ -88,126 +129,23 @@ void FoamCoupling::insertBodyId(int bId)
 	bodyListModified = true;
 }
 
-void FoamCoupling::eraseId(int bId)
+bool FoamCoupling::eraseId(int bId)
 {
 	auto it = std::find(bodyList.begin(), bodyList.end(), bId);
 	if (it != bodyList.end()) {
 		bodyList.erase(it);
-		bodyListModified = true;
+		return true;
 	} else {
 		LOG_ERROR("Id not found in list of ids in coupling");
+		return false;
 	}
+	bodyListModified = true;
 }
 
 
-int FoamCoupling::getNumBodies() const { return bodyList.size(); }
-
-std::vector<int> FoamCoupling::getIdList() const { return bodyList; }
-
-void FoamCoupling::castParticle()
-{
-	int sz = bodyList.size();
-	MPI_Bcast(&sz, 1, MPI_INT, rank, MPI_COMM_WORLD);
-
-	procList.resize(sz);
-	hydroForce.resize(sz * 6);
-	particleData.resize(10 * sz);
-
-	std::fill(procList.begin(), procList.end(), -1);
-	std::fill(hydroForce.begin(), hydroForce.end(), 0.0);
-
-#ifdef YADE_OPENMP
-#pragma omp parallel for collapse(1)
-#endif
-
-	for (unsigned int i = 0; i < bodyList.size(); ++i) {
-		const Body* b = (*scene->bodies)[bodyList[i]].get();
-		if (scene->isPeriodic) {
-			const Vector3r& pos      = scene->cell->wrapPt(b->state->pos);
-			particleData[i * 10]     = pos[0];
-			particleData[i * 10 + 1] = pos[1];
-			particleData[i * 10 + 2] = pos[2];
-		} else {
-			particleData[i * 10]     = b->state->pos[0];
-			particleData[i * 10 + 1] = b->state->pos[1];
-			particleData[i * 10 + 2] = b->state->pos[2];
-		}
-		particleData[i * 10 + 3] = b->state->vel[0];
-		particleData[i * 10 + 4] = b->state->vel[1];
-		particleData[i * 10 + 5] = b->state->vel[2];
-		particleData[i * 10 + 6] = b->state->angVel[0];
-		particleData[i * 10 + 7] = b->state->angVel[1];
-		particleData[i * 10 + 8] = b->state->angVel[2];
-		shared_ptr<Sphere> s     = YADE_PTR_DYN_CAST<Sphere>(b->shape);
-		particleData[i * 10 + 9] = s->radius;
-	}
-
-	MPI_Bcast(&particleData.front(), particleData.size(), MPI_DOUBLE, rank, MPI_COMM_WORLD);
-	// clear array after bcast
-	particleData.clear();
-}
-
-void FoamCoupling::castNumParticle(int value) { MPI_Bcast(&value, 1, MPI_INT, rank, MPI_COMM_WORLD); }
-
-
-void FoamCoupling::castTerminate()
-{
-	int value = 10;
-	MPI_Bcast(&value, 1, MPI_INT, rank, MPI_COMM_WORLD);
-}
-
-void FoamCoupling::updateProcList()
-{
-	for (unsigned int i = 0; i != bodyList.size(); ++i) {
-		int dummy_val = -5;
-		MPI_Allreduce(&dummy_val, &procList[i], 1, MPI_INT, MPI_MAX, MPI_COMM_WORLD);
-		if (procList[i] < 0) LOG_WARN("particle id" << i << "not found in FOAM" << std::endl);
-	}
-}
-
-void FoamCoupling::recvHydroForce()
-{
-	std::fill(hydroForce.begin(), hydroForce.end(), 0.0);
-	for (unsigned int i = 0; i != procList.size(); ++i) {
-		int                 recvFrom = procList[i];
-		std::vector<double> fBuff(6, 0.0);
-		MPI_Recv(&fBuff.front(), 6, MPI_DOUBLE, recvFrom, TAG_FORCE, MPI_COMM_WORLD, &status);
-		for (unsigned int j = 0; j != 6; ++j) {
-			hydroForce[6 * i + j] = fBuff[j];
-		}
-	}
-}
-
-void FoamCoupling::setHydroForce()
-{
-	// clear hydroforce before summation
-
-#ifdef YADE_OPENMP
-#pragma omp parallel for collapse(1)
-#endif
-	for (unsigned int i = 0; i < bodyList.size(); ++i) {
-		const Vector3r& fx = Vector3r(hydroForce[6 * i], hydroForce[6 * i + 1], hydroForce[6 * i + 2]);
-		const Vector3r& tx = Vector3r(hydroForce[6 * i + 3], hydroForce[6 * i + 4], hydroForce[6 * i + 5]);
-		scene->forces.addForce(bodyList[i], fx);
-		scene->forces.addTorque(bodyList[i], tx);
-	}
-}
-
-void FoamCoupling::sumHydroForce()
-{
-	// clear the vector
-	std::fill(hydroForce.begin(), hydroForce.end(), 0.0);
-	Real dummy_val = 0.0;
-	for (unsigned int i = 0; i != bodyList.size(); ++i) {
-		for (unsigned int j = 0; j != 6; ++j) {
-			MPI_Allreduce(&dummy_val, &hydroForce[6 * i + j], 1, MPI_DOUBLE, MPI_SUM, MPI_COMM_WORLD);
-		}
-	}
-}
-
-
-void FoamCoupling::resetProcList() { procList.clear(); }
+int FoamCoupling::getNumBodies() { return bodyList.size(); }
 
+std::vector<int> FoamCoupling::getIdList() { return bodyList; }
 
 void FoamCoupling::exchangeDeltaT()
 {
@@ -215,13 +153,13 @@ void FoamCoupling::exchangeDeltaT()
 	MPI_Recv(&foamDeltaT, 1, MPI_DOUBLE, 1, TAG_FLUID_DT, MPI_COMM_WORLD, &status);
 	//bcast yadedt to others.
 	Real yadeDt = scene->dt;
-	MPI_Bcast(&yadeDt, 1, MPI_DOUBLE, rank, MPI_COMM_WORLD);
+	MPI_Bcast(&yadeDt, 1, MPI_DOUBLE, rank, INTRACOMM);
 	// calculate the interval . TODO: to include hydrodynamic time scale if inertial in openfoam
 	// here -> hDeltaT = getViscousTimeScale();
 	dataExchangeInterval = (long int)((yadeDt < foamDeltaT) ? foamDeltaT / yadeDt : 1);
 }
 
-Real FoamCoupling::getViscousTimeScale() const
+Real FoamCoupling::getViscousTimeScale()
 {
 	//  Real hDeltaT = 0.0;
 	//  Real dummy = 1e9;
@@ -232,84 +170,46 @@ Real FoamCoupling::getViscousTimeScale() const
 }
 
 
-/***********parallel version *******/
-
 void FoamCoupling::getFluidDomainBbox()
 {
-	/* get the bounding box of the grid from each fluid solver processes, this gird minmax is used to set the min/max of the body of shape FluidDomainBbox. 
-	 All Yade processes have ranks from 0 to yadeCommSize - 1 in the  MPI_COMM_WORLD communicator, the fluid Ranks are then from yadeCommSize to size(M
-	 PI_COMM_WORLD) -1, all yade ranks receive the min max of the fluid domains, and insert it to their body containers. The fluid subdomain bodies have subdomain=0, they are actually owned 
+	/* get the bounding box of the grid from each fluid solver processes, this gird minmax is used to set the min/max of the body of shape FluidDomainBbox.
+	 All Yade processes have ranks from 0 to yadeCommSize - 1 in the  INTRACOMM communicator, the fluid Ranks are then from yadeCommSize to size(M
+	 PI_COMM_WORLD) -1, all yade ranks receive the min max of the fluid domains, and insert it to their body containers. The fluid subdomain bodies have subdomain=0, they are actually owned
 	 by the master process (rank=0) in the yade communicator. */
-
-	// local commsize and rank
-
-	MPI_Comm_rank(selfComm(), &localRank);
-	MPI_Comm_size(selfComm(), &localCommSize);
-	//world comm size and world rank
-
-	MPI_Comm_size(MPI_COMM_WORLD, &worldCommSize);
-	MPI_Comm_rank(MPI_COMM_WORLD, &worldRank);
-
-
-	commSzdff = abs(localCommSize - worldCommSize);
-
-	stride = localCommSize;
-
 	std::vector<std::vector<double>> minMaxBuff;
 
 	//alloc memory
-	for (int i = 0; i != commSzdff; ++i) {
+	for (int i = 0; i != foamCommSize; ++i) {
 		std::vector<double> buff(6, 1e-50);
 		minMaxBuff.push_back(buff);
 	}
 
-
-	//recv the grid minmax from fluid solver.
-
-	for (int rnk = 0; rnk != commSzdff; ++rnk) {
-		MPI_Status           status2;
+	//recv the grid minmax from each rank from foam solver. The FOAM ranks are 'higher', i.e. in the INTRACOMM, they follow after the Yade ranks.
+	for (int rnk = 0; rnk != foamCommSize; ++rnk) {
+		// MPI_Status status;
 		std::vector<double>& buff = minMaxBuff[rnk];
-		MPI_Recv(&buff.front(), 6, MPI_DOUBLE, rnk + stride, TAG_GRID_BBOX, MPI_COMM_WORLD, &status2);
+		MPI_Recv(&buff.front(), 6, MPI_DOUBLE, rnk + stride, TAG_GRID_BBOX, INTRACOMM, &status);
 	}
 
-	fluidDomains.resize(commSzdff);
+	//
+	fluidDomains.resize(foamCommSize);
 	//create fluidDomainBbox bodies and get their ids.
-	for (int fd = 0; fd != commSzdff; ++fd) {
+	for (int fd = 0; fd != foamCommSize; ++fd) {
 		shared_ptr<Body>            flBody(shared_ptr<Body>(new Body()));
 		shared_ptr<FluidDomainBbox> flBodyshape(shared_ptr<FluidDomainBbox>(new FluidDomainBbox()));
 		flBodyshape->setMinMax(minMaxBuff[fd]);
 		flBodyshape->domainRank      = stride + fd;
 		flBodyshape->hasIntersection = false;
 		flBody->shape                = flBodyshape;
-		flBody->subdomain            = 0;
+		//if (!serialYade) {flBody->subdomain = 0; } else {flBody->subdomain=1;} // simply assigning a  dummy so that it works in serial case ( single yade proc)
 		flBody->setIsFluidDomainBbox(true);
 		fluidDomains[fd] = scene->bodies->insert(flBody);
 	}
-	minMaxBuff.clear(); // dealloc the recvd minMaxBuff;
 }
 
-
-/*
-void FoamCoupling::buildSharedIdsMapv2(){
-	for (const auto& flId : fluidDomains){
-		const shared_ptr<Body>& flbody = Body::byId(flId, scene);
-		if (flbody){
-			const shared_ptr<FluidDomainBbox>& flbox = YADE_PTR_CAST<FluidDomainBbox>(flbody->shape); 
-			for (const auto& flIntrs : flbdy->intrs){
-				Body::id_t otherBodyId; 
-				if (flId == intr->getId1()) {otherBodyId = flIntrs->getId2(); } else {otherBodyId==flIntrs->getId2()}
-				if (!ifDomainBodies(*scene->bodies[otherBodyId])){
-					flbox->hasIntersection = true; 
-					flbox->bIds.push_back(otherBodyId); 
-				}
-			}
-		}
-	}
-}*/
-
 void FoamCoupling::buildSharedIdsMap()
 {
-	/*Builds the list of ids interacting with a fluid subdomain and stores those body ids that has intersections with several fluid domains. 
+	/*Builds the list of ids interacting with a fluid subdomain and stores those body ids that has intersections with several fluid domains.
 	 sharedIdsMapIndx = a vector of std::pair<Body::id_t, std::map<fluidDomainId, indexOfthebodyinthefluidDomain aka index in flbdy-> bIds> > */
 
 	inCommunicationProc.clear();
@@ -330,7 +230,9 @@ void FoamCoupling::buildSharedIdsMap()
 			if (otherBody->getIsFluidDomainBbox()) {
 				const shared_ptr<FluidDomainBbox>& flbox = YADE_PTR_CAST<FluidDomainBbox>(otherBody->shape);
 				flbox->bIds.push_back(bodyId);
-				if (!flbox->hasIntersection) { flbox->hasIntersection = true; }
+				if (!flbox->hasIntersection) {
+					flbox->hasIntersection = true;
+				}
 				int indx = (flbox->bIds.size()) - 1;
 				testMap.insert(std::make_pair(
 				        otherId,
@@ -347,36 +249,10 @@ void FoamCoupling::buildSharedIdsMap()
 		const shared_ptr<Body>& flb = (*scene->bodies)[fluidId];
 		if (flb) {
 			const shared_ptr<FluidDomainBbox>& flBox = YADE_PTR_CAST<FluidDomainBbox>(flb->shape);
-			if (flBox->bIds.size() > 0) { inCommunicationProc.push_back(std::make_pair(flBox->domainRank, flBox->bIds.size())); }
-		}
-	}
-}
-
-
-//unused.
-void FoamCoupling::buildSharedIds()
-{
-	/*It is possible to have one yade body to have interactions with several  fluid subdomains, (we just have the bounding box of the fluid domain, the fluid domain is a regular polygon with several faces). 
-	 Building a list of those ids which are have several interactions helps to identify those fliud procs from whom to receive the hydrodynamic force and tracking. This is used in the function 
-	verifyParticleDetection. */
-
-	const shared_ptr<Subdomain>& subD = YADE_PTR_CAST<Subdomain>(scene->subD);
-	for (int bodyId = 0; bodyId != static_cast<int>(subD->ids.size()); ++bodyId) {
-		std::vector<Body::id_t> fluidIds;
-		const shared_ptr<Body>& testBody = (*scene->bodies)[subD->ids[bodyId]];
-		for (const auto& bIntrs : testBody->intrs) {
-			const shared_ptr<Interaction>& intr = bIntrs.second;
-			Body::id_t                     otherId;
-			if (testBody->id == intr->getId1()) {
-				otherId = intr->getId2();
-			} else {
-				otherId = intr->getId1();
+			if (flBox->bIds.size() > 0) {
+				inCommunicationProc.push_back(std::make_pair(flBox->domainRank, flBox->bIds.size()));
 			}
-			if (ifFluidDomain(otherId)) { fluidIds.push_back(otherId); }
 		}
-		if (fluidIds.size() > 1) {
-			sharedIds.push_back(std::make_pair(subD->ids[bodyId], fluidIds));
-		} // this body has interaction with  more than one fluid  grids.
 	}
 }
 
@@ -389,37 +265,38 @@ int FoamCoupling::ifSharedIdMap(const Body::id_t& testId)
 		return testId == elem.first;
 	});
 
-	if (it != sharedIdsMapIndx.end()) { res = it - sharedIdsMapIndx.begin(); }
-	return res;
-}
-
-bool FoamCoupling::ifFluidDomain(const Body::id_t& testId)
-{
-	/* function to check if the body is fluidDomainBox*/
-	const auto& iter = std::find(fluidDomains.begin(), fluidDomains.end(), testId);
-	if (iter != fluidDomains.end()) {
-		return true;
-	} else {
-		return false;
+	if (it != sharedIdsMapIndx.end()) {
+		res = it - sharedIdsMapIndx.begin();
 	}
+	return res;
 }
 
 
 void FoamCoupling::buildLocalIds()
 {
-	if (localRank == yadeMaster) { return; } // master has no bodies.
+	//if (localRank==yadeMaster and not serialYade) { return; }  // master has no bodies.
 	if (bodyList.size() == 0) {
 		LOG_ERROR("Ids for coupling has no been set, FAIL!");
 		return;
 	}
-	const shared_ptr<Subdomain>& subD = YADE_PTR_CAST<Subdomain>(scene->subD);
-	if (!subD) {
-		LOG_ERROR("subdomain not found for local rank/ world rank  = " << localRank << "   " << worldRank);
-		return;
-	}
-	for (const auto& testId : bodyList) {
-		std::vector<Body::id_t>::iterator iter = std::find(subD->ids.begin(), subD->ids.end(), testId); // can subD have ids sorted?
-		if (iter != subD->ids.end()) { localIds.push_back(*iter); }
+	if (!serialYade) {
+		if (localRank > yadeMaster) {
+			const shared_ptr<Subdomain>& subD = YADE_PTR_CAST<Subdomain>(scene->subD);
+			if (!subD) {
+				LOG_ERROR("subdomain not found for local rank/ world rank  = " << localRank << "   " << worldRank);
+				return;
+			}
+			for (const auto& testId : bodyList) {
+				std::vector<Body::id_t>::iterator iter = std::find(subD->ids.begin(), subD->ids.end(), testId); // can subD have ids sorted?
+				if (iter != subD->ids.end()) {
+					localIds.push_back(*iter);
+				}
+			}
+		} else {
+			return;
+		}
+	} else {
+		localIds = bodyList;
 	}
 }
 
@@ -448,14 +325,12 @@ void FoamCoupling::sendIntersectionToFluidProcs()
 	// notify the fluid procs about intersection based on number of intersecting bodies.
 	// vector of sendRecvRanks, with each vector element containing the number of bodies, if no bodies, send negative val.
 	std::vector<int> sendRecvRanks(fluidDomains.size(), -1);
-
 	for (unsigned f = 0; f != fluidDomains.size(); ++f) {
 		const shared_ptr<Body>& fdomain = (*scene->bodies)[fluidDomains[f]];
 		if (fdomain) {
 			const shared_ptr<FluidDomainBbox>& fluidBox = YADE_PTR_CAST<FluidDomainBbox>(fdomain->shape);
 			if (fluidBox->bIds.size() > 0) {
 				sendRecvRanks[f] = fluidBox->bIds.size();
-
 			} else {
 				sendRecvRanks[f] = -1;
 			}
@@ -466,10 +341,9 @@ void FoamCoupling::sendIntersectionToFluidProcs()
 	//
 	int buffSz = fluidDomains.size();
 
-	//MPI_Send ..
 
-	for (int rnk = 0; rnk != commSzdff; ++rnk) {
-		MPI_Send(&sendRecvRanks.front(), buffSz, MPI_INT, rnk + stride, TAG_SZ_BUFF, MPI_COMM_WORLD);
+	for (int rnk = 0; rnk != foamCommSize; ++rnk) {
+		MPI_Send(&sendRecvRanks.front(), buffSz, MPI_INT, rnk + stride, TAG_SZ_BUFF, INTRACOMM);
 	}
 }
 
@@ -482,7 +356,7 @@ void FoamCoupling::sendBodyData()
 		if (flbody) {
 			const shared_ptr<FluidDomainBbox> flbox = YADE_PTR_CAST<FluidDomainBbox>(flbody->shape);
 			if (flbox->hasIntersection) {
-				std::vector<Real> prtData(10 * flbox->bIds.size(), 1e-50);
+				std::vector<double> prtData(10 * flbox->bIds.size(), 1e-50);
 				for (unsigned int i = 0; i != flbox->bIds.size(); ++i) {
 					const shared_ptr<Body>& b = (*scene->bodies)[flbox->bIds[i]];
 					if (isPeriodic) {
@@ -506,9 +380,8 @@ void FoamCoupling::sendBodyData()
 					const shared_ptr<Sphere>& sph = YADE_PTR_CAST<Sphere>(b->shape);
 					prtData[10 * i + 9]           = sph->radius;
 				}
-
 				int sz = prtData.size();
-				MPI_Send(&prtData.front(), sz, MPI_DOUBLE, flbox->domainRank, TAG_PRT_DATA, MPI_COMM_WORLD);
+				MPI_Send(&prtData.front(), sz, MPI_DOUBLE, flbox->domainRank, TAG_PRT_DATA, INTRACOMM);
 			}
 		}
 	}
@@ -517,11 +390,11 @@ void FoamCoupling::sendBodyData()
 
 void FoamCoupling::verifyParticleDetection()
 {
-	/* check if the sent particles are located on the fluid procs, verify all particles (in fluid coupling) owned by the yade process has been accounted for. Some particles may intersect the 
-	 fluid domains bounding box but may not be actually inside the fluid mesh. 
-	 Method : Everty fluid proc sents a vector of it's search result. if found res = 1, else res =0, for each particle. 
-	 each yade rank receives this vector from intersecting fluid ranks, looks through the vector to find the fails. 
-	 if fail is found : see if this id is a sharedid. if not this particle has been 'lost'. if shared id :  check the vector of verifyTracking of the intersecting fluid domain till found in 
+	/* check if the sent particles are located on the fluid procs, verify all particles (in fluid coupling) owned by the yade process has been accounted for.
+	Some particles may intersect the  fluid domains bounding box but may not be actually inside the fluid mesh.
+	 Method : Everty fluid proc sents a vector of it's search result. if found res = 1, else res =0, for each particle.
+	 each yade rank receives this vector from intersecting fluid ranks, looks through the vector to find the fails.
+	 if fail is found : see if this id is a sharedid. if not this particle has been 'lost'. if shared id :  check the vector of verifyTracking of the intersecting fluid domain till found in
 	 at least one intersecting fluid box. if not particle has been lost. */
 
 	//std::map<int, std::vector<int> > verifyTracking;  //vector containing domainRank, vector of "found/misses" for each body, miss = -1, found = 1.
@@ -537,9 +410,9 @@ void FoamCoupling::verifyParticleDetection()
 	for (auto& it : verifyTracking) {
 		std::vector<int>& vt  = it.second;
 		int               rnk = it.first;
-		MPI_Status        status2;
-		int               buffSz = vt.size();
-		MPI_Recv(&vt.front(), buffSz, MPI_INT, rnk, TAG_SEARCH_RES, MPI_COMM_WORLD, &status2);
+		// MPI_Status status;
+		int buffSz = vt.size();
+		MPI_Recv(&vt.front(), buffSz, MPI_INT, rnk, TAG_SEARCH_RES, INTRACOMM, &status);
 	}
 
 
@@ -570,17 +443,24 @@ void FoamCoupling::verifyParticleDetection()
 		}
 	}
 
-	// check if the 'sharedIds' has been located in any of the fluid procs.
+	//check if the 'sharedIds' has been located in any of the fluid procs.  (REWRITE FROM HERE)
 	if (unFoundSharedIds.size() > 0) {
 		for (const auto& idPair : sharedIdsMapIndx) {
-			const auto& bodyId = idPair.first;
+			const auto& bodyId     = idPair.first;
+			int         foundCount = 0;
 			//const int mpSz = idPair.second.size();
 			bool found = false;
 			for (const auto& fdIndx : idPair.second) {
 				const shared_ptr<FluidDomainBbox>& flbox = YADE_PTR_CAST<FluidDomainBbox>((*scene->bodies)[fdIndx.first]->shape);
 				for (const auto& vt : verifyTracking) {
 					if (vt.first == flbox->domainRank) {
-						if (vt.second[fdIndx.second] > 0) found = true;
+						if (vt.second[fdIndx.second] > 0) {
+							found = true;
+							++foundCount;
+							//  uncomment me for debugging..
+							//   std::cout << "foundcount for bId = " <<  idPair.first <<  "  " << foundCount << std::endl;
+							//   std::cout << "totsize for bId = " <<  idPair.first <<  "  " << idPair.second.size() << std::endl;
+						}
 					}
 				}
 			}
@@ -593,13 +473,107 @@ void FoamCoupling::verifyParticleDetection()
 			}
 		}
 	}
+
+	// 	for (auto& idPair : sharedIdsMapIndx){
+	// 		for (auto iter = idPair.second.cbegin(); iter != idPair.second.cend();){
+	// 			auto fdIndx = *iter;
+	// 			const shared_ptr<FluidDomainBbox>& flbox = YADE_PTR_CAST<FluidDomainBbox>((*scene->bodies)[fdIndx.first]->shape);
+	// 			for (const auto& vt : verifyTracking){
+	// 				if (vt.first == flbox->domainRank){
+	// 					if (vt.second[fdIndx.second] > 0) {
+	// 					  ; ++iter;}
+	// 				} else {
+	// 					idPair.second.erase(iter++); // remove proc and indx from sharedIdsMap
+	// 				}
+	// 			}
+	// 		}
+	// 	}
+
+
+	// 	for (const auto& idPair : sharedIdsMapIndx){
+	// 		if (!idPair.second.size()) {
+	// 			const auto& bodyId = idPair.first;
+	// 			const Vector3r& pos = (*scene->bodies)[bodyId]->state->pos;
+	// 			LOG_ERROR("Particle ID (SHARED ID )  = " << bodyId << " pos = " << pos[0] << " " << pos[1] << " " << pos[2] <<  " was not found in fluid domain" << " lost particle in proc " << localRank);
+	// 		}
+	// 	}
+
+	std::vector<int>                           sharedIdsCount(inCommunicationProc.size(), 0);
+	std::vector<std::vector<std::vector<int>>> sharedBuff;
+	sharedBuff.resize(inCommunicationProc.size());
+
+	// 	//prepare to send shared ids
+	for (int ii = 0; ii != (int)inCommunicationProc.size(); ++ii) {
+		for (const auto& idPair : sharedIdsMapIndx) {
+			const auto& indxMap = idPair.second;
+			// if and only if the size of the map is > 1, the particle has been found in more than one foam procs.
+			if (indxMap.size() > 1) {
+				const auto& indx = findRankSharedIndxMap(indxMap, inCommunicationProc[ii].first);
+				if (indx >= 0) {
+					std::vector<int> buff;
+					buff.push_back(indx); // index of the id in the fluid proc's lst of particles
+					for (const auto& val : indxMap) {
+						const auto& flbx = YADE_PTR_CAST<FluidDomainBbox>((*scene->bodies)[val.first]->shape);
+						if (inCommunicationProc[ii].first == flbx->domainRank) continue;
+						buff.push_back(val.first);
+					}
+					sharedBuff[ii].push_back(buff);
+				}
+			}
+		}
+	}
+	// send info on number of 'shared' ids
+	std::vector<MPI_Request> mpiReqs;
+	for (unsigned i = 0; i != sharedBuff.size(); ++i) {
+		int         buffSz = (int)sharedBuff[i].size();
+		MPI_Request req;
+		MPI_Isend(&buffSz, 1, MPI_INT, inCommunicationProc[i].first, TAG_SHARED_ID, INTRACOMM, &req);
+		mpiReqs.push_back(req);
+	}
+
+
+	for (auto& req : mpiReqs) {
+		// MPI_Status status;
+		MPI_Wait(&req, &status);
+	}
+
+	mpiReqs.clear();
+
+
+	for (unsigned i = 0; i != sharedBuff.size(); ++i) {
+		if (!sharedBuff[i].size()) continue;
+		for (unsigned j = 0; j != sharedBuff[i].size(); ++j) {
+			MPI_Request       req;
+			std::vector<int>& buff = sharedBuff[i][j];
+			int               sz   = (int)buff.size();
+			MPI_Isend(&buff.front(), sz, MPI_INT, inCommunicationProc[i].first, TAG_SHARED_ID, INTRACOMM, &req);
+			mpiReqs.push_back(req);
+		}
+	}
+	if (mpiReqs.size()) {
+		for (auto& rq : mpiReqs) {
+			// MPI_Status status;
+			MPI_Wait(&rq, &status);
+		}
+		mpiReqs.clear();
+	}
 }
 
+
+int FoamCoupling::findRankSharedIndxMap(const std::map<int, int>& tMap, const int& rnk)
+{
+	// if found, return the index of the particle
+	for (const auto& prcIndx : tMap) {
+		const auto& flbx = YADE_PTR_CAST<FluidDomainBbox>((*scene->bodies)[prcIndx.first]->shape);
+		if (rnk == flbx->domainRank) return prcIndx.second; // return the particle index
+	}
+	return -1;
+}
+
+
 void FoamCoupling::getParticleForce()
 {
 	hForce.clear();
-
-
 	for (const auto& proc : inCommunicationProc) {
 		std::vector<double> forceVec(6 * proc.second, 0.0);
 		hForce.push_back(std::make_pair(proc.first, std::move(forceVec)));
@@ -610,9 +584,9 @@ void FoamCoupling::getParticleForce()
 		std::vector<double>& tmpForce = recvForce.second;
 		int                  recvRank = recvForce.first;
 		int                  buffSz   = tmpForce.size();
-		MPI_Status           status2;
-		/* fluid procs having no particles will send 0 force, torque */
-		MPI_Recv(&tmpForce.front(), buffSz, MPI_DOUBLE, recvRank, TAG_FORCE, MPI_COMM_WORLD, &status2);
+
+		/* fluid procs having no particles (those in inCommunicationProc) will send 0 force, torque */
+		MPI_Recv(&tmpForce.front(), buffSz, MPI_DOUBLE, recvRank, TAG_FORCE, INTRACOMM, &status);
 	}
 }
 
@@ -620,6 +594,9 @@ void FoamCoupling::getParticleForce()
 void FoamCoupling::resetFluidDomains()
 {
 	// clear the vector ids held fluidDomainBbox->bIds
+	if (localRank == yadeMaster and not serialYade) {
+		return;
+	}
 	for (unsigned f = 0; f != fluidDomains.size(); ++f) {
 		const shared_ptr<Body>& fdomain = (*scene->bodies)[fluidDomains[f]];
 		if (fdomain) {
@@ -629,14 +606,15 @@ void FoamCoupling::resetFluidDomains()
 	}
 	sharedIdsMapIndx.clear();
 	localIds.clear();
-	//inCommunicationProc.clear();
 }
 
 
-void FoamCoupling::setHydroForceParallel()
+void FoamCoupling::setHydroForce()
 {
 	// add the force
-	if (localRank == yadeMaster) { return; }
+	if (localRank == yadeMaster and not serialYade) {
+		return;
+	}
 	for (const auto& rf : hForce) {
 		int                                indx     = abs(rf.first - localCommSize);
 		const std::vector<double>&         forceVec = rf.second;
@@ -659,86 +637,89 @@ void FoamCoupling::setHydroForceParallel()
 void FoamCoupling::exchangeDeltaTParallel()
 {
 	// Recv foamdt  first and broadcast;
+	if (!serialYade) {
+		if (localRank == yadeMaster) {
+			// MPI_Status status;
+			int fluidMaster = stride;
+			MPI_Recv(&foamDeltaT, 1, MPI_DOUBLE, fluidMaster, TAG_FLUID_DT, INTRACOMM, &status);
+		}
 
-	if (localRank == yadeMaster) {
-		MPI_Status status2;
-		int        fluidMaster = stride;
-		MPI_Recv(&foamDeltaT, 1, MPI_DOUBLE, fluidMaster, TAG_FLUID_DT, MPI_COMM_WORLD, &status2);
+		//bcast  the fluidDt to all yade_procs.
+		// Real  yadeDt = scene-> dt;
+		MPI_Bcast(&foamDeltaT, 1, MPI_DOUBLE, yadeMaster, selfComm());
+
+		//do a MPI_Allreduce (min) and get the minDt of all the yade procs..
+		Real myDt = scene->dt;
+		Real yadeDt;
+		MPI_Allreduce(&myDt, &yadeDt, 1, MPI_DOUBLE, MPI_MIN, selfComm());
+
+
+		// send the minDt to fluid proc (master .. )
+		if (localRank == yadeMaster) {
+			int fluidMaster = stride;
+			MPI_Send(&yadeDt, 1, MPI_DOUBLE, fluidMaster, TAG_YADE_DT, INTRACOMM);
+		}
+
+		// calculate the interval . TODO: to include hydrodynamic time scale if inertial in openfoam
+		// here -> hDeltaT = getViscousTimeScale();
+		dataExchangeInterval = (long int)((yadeDt < foamDeltaT) ? foamDeltaT / yadeDt : 1);
+	} else {
+		exchangeDeltaT();
 	}
-
-	//bcast  the fluidDt to all yade_procs.
-	// Real  yadeDt = scene-> dt;
-	MPI_Bcast(&foamDeltaT, 1, MPI_DOUBLE, yadeMaster, selfComm());
-
-	//do a MPI_Allreduce (min) and get the minDt of all the yade procs..
-	Real myDt = scene->dt;
-	Real yadeDt;
-	MPI_Allreduce(&myDt, &yadeDt, 1, MPI_DOUBLE, MPI_MIN, selfComm());
-
-
-	// send the minDt to fluid proc (master .. )
-	if (localRank == yadeMaster) {
-		int fluidMaster = stride;
-		MPI_Send(&yadeDt, 1, MPI_DOUBLE, fluidMaster, TAG_YADE_DT, MPI_COMM_WORLD);
-	}
-
-	// calculate the interval . TODO: to include hydrodynamic time scale if inertial in openfoam
-	// here -> hDeltaT = getViscousTimeScale();
-	dataExchangeInterval = (long int)((yadeDt < foamDeltaT) ? foamDeltaT / yadeDt : 1);
 }
 
-
 void FoamCoupling::runCoupling()
 {
-	castParticle();
-	updateProcList();
-	if (isGaussianInterp) {
-		sumHydroForce();
-	} else {
-		recvHydroForce();
-	}
-}
-
-void FoamCoupling::runCouplingParallel()
-{
-	if (localRank > yadeMaster) { // master proc does not take part in the coupling except for timestep exchange and  receiving the grid minmax
+	if (localRank > yadeMaster or serialYade) {
 		buildLocalIds();
 		buildSharedIdsMap();
 		sendIntersectionToFluidProcs();
 		sendBodyData();
 		verifyParticleDetection();
 		getParticleForce();
-		//setParticleForceParallel();
 	}
 }
 
 void FoamCoupling::action()
 {
-	if (!commSizeSet) { getRank(); }
-
-	if (!couplingModeParallel) {
-		if (exchangeData()) {
-			runCoupling();
-			exchangeDeltaT();
-		}
-		setHydroForce();
-	} else {
-		if (exchangeData()) {
-			resetFluidDomains();
-			runCouplingParallel();
-			exchangeDeltaTParallel();
-		}
-		setHydroForceParallel();
+	if (!initDone) {
+		StartFoamSolver();
 	}
+	if (exchangeData()) {
+		resetFluidDomains();
+		runCoupling();
+		exchangeDeltaTParallel();
+	}
+	setHydroForce();
 }
 
 bool FoamCoupling::exchangeData() { return scene->iter % dataExchangeInterval == 0; }
 
+
 void FoamCoupling::killMPI()
 {
-	castTerminate();
-	if (!couplingModeParallel) MPI_Finalize();
+	//  int value = 1;  // Use the same value as in OpenFOAM
+	// MPI_Bcast(&value, 1, MPI_INT, 0, INTRACOMM);  // Broadcast from rank 0 in Yade
+
+	// Now sync all processes
+
+	//MPI_Barrier(INTRACOMM);
+	// MPI_Finalize();  // Finalize MPI
+	MPI_Abort(INTRACOMM, -100);
 }
+
+void FoamCoupling::checkFoamVersion()
+{
+	const char* wmProjectDir = std::getenv("WM_PROJECT_DIR");
+	if (wmProjectDir != nullptr) {
+		foamPath = std::string(wmProjectDir);
+		string version(std::getenv("WM_PROJECT_VERSION"));
+		if (!version.empty() && version.front() == 'v') //remove the leading 'v'
+			version.erase(0, 1);
+		foamVersion = std::stoi(version);
+	}
+}
+
 } // namespace yade
 
 #endif
