@@ -168,6 +168,8 @@ bool do_intersect(Polyhedron A, Polyhedron B, std::vector<int>& sep_plane)
 	bool found;
 	//check previous separation plane
 	switch (sep_plane[0]) {
+		case 0: //no prior information about separation plane
+			break;
 		case 1: //separation plane was previously determined as sep_plane[2]-th plane of A polyhedron
 		{
 			if (unlikely((unsigned)sep_plane[2] >= A.size_of_facets())) break;
@@ -604,9 +606,9 @@ Polyhedron Polyhedron_Plane_intersection(Polyhedron A, Plane B, CGALpoint centro
 	Intersection = ConvexHull(dual_planes);
 	if (Intersection.empty()) return Intersection;
 
-	//simplify
-	std::transform(Intersection.facets_begin(), Intersection.facets_end(), Intersection.planes_begin(), Plane_equation());
-	Intersection = Simplify(Intersection, SIMPLIFY_LIMIT);
+	//simplify - turn off simplification in the interaction computations
+	//std::transform(Intersection.facets_begin(), Intersection.facets_end(), Intersection.planes_begin(), Plane_equation());
+	//Intersection = Simplify(Intersection, SIMPLIFY_LIMIT);
 	std::transform(Intersection.facets_begin(), Intersection.facets_end(), Intersection.planes_begin(), Plane_equation());
 
 	//dualize again
@@ -726,9 +728,9 @@ Polyhedron Polyhedron_Polyhedron_intersection(Polyhedron A, Polyhedron B, CGALpo
 	Intersection = ConvexHull(dual_planes);
 	if (Intersection.empty()) return Intersection;
 
-	//simplify
-	std::transform(Intersection.facets_begin(), Intersection.facets_end(), Intersection.planes_begin(), Plane_equation());
-	Intersection = Simplify(Intersection, SIMPLIFY_LIMIT);
+	//simplify - turn off simplification in the interaction computations
+	//std::transform(Intersection.facets_begin(), Intersection.facets_end(), Intersection.planes_begin(), Plane_equation());
+	//Intersection = Simplify(Intersection, SIMPLIFY_LIMIT);
 	std::transform(Intersection.facets_begin(), Intersection.facets_end(), Intersection.planes_begin(), Plane_equation());
 
 	//dualize again
