@@ -17,8 +17,6 @@
 #include <pkg/common/InsertionSortCollider.hpp>
 #include <pkg/dem/GlobalStiffnessTimeStepper.hpp>
 #include <pkg/dem/NewtonIntegrator.hpp>
-//#include <preprocessing/dem/Shop.hpp>
-#include <boost/filesystem/convenience.hpp>
 #include <boost/lexical_cast.hpp>
 #include <boost/limits.hpp>
 #include <boost/numeric/conversion/bounds.hpp>
