@@ -69,9 +69,7 @@ static PyObject* set(PygtsPoint* self, PyObject* args)
 	SELF_CHECK
 
 	/* Parse the args */
-	if (!PyArg_ParseTuple(args, "|ddd", &x, &y, &z)) {
-		return NULL;
-	}
+	if (!PyArg_ParseTuple(args, "|ddd", &x, &y, &z)) { return NULL; }
 
 	gts_point_set(PYGTS_POINT_AS_GTS_POINT(self), x, y, z);
 
@@ -98,9 +96,7 @@ static PyObject* is_in_rectangle(PygtsPoint* self, PyObject* args)
 	SELF_CHECK
 
 	/* Parse the args */
-	if (!PyArg_ParseTuple(args, "OO", &o1_, &o2_)) {
-		return NULL;
-	}
+	if (!PyArg_ParseTuple(args, "OO", &o1_, &o2_)) { return NULL; }
 
 	/* Convert to PygtsObjects */
 	if (!(pygts_point_check(o1_) && pygts_point_check(o2_))) {
@@ -145,9 +141,7 @@ static PyObject* distance(PygtsPoint* self, PyObject* args)
 	SELF_CHECK
 
 	/* Parse the args */
-	if (!PyArg_ParseTuple(args, "O", &o_)) {
-		return NULL;
-	}
+	if (!PyArg_ParseTuple(args, "O", &o_)) { return NULL; }
 
 	/* Convert to PygtsObjects */
 	if (pygts_point_check(o_)) {
@@ -187,9 +181,7 @@ static PyObject* distance2(PygtsPoint* self, PyObject* args)
 	SELF_CHECK
 
 	/* Parse the args */
-	if (!PyArg_ParseTuple(args, "O", &o_)) {
-		return NULL;
-	}
+	if (!PyArg_ParseTuple(args, "O", &o_)) { return NULL; }
 
 	/* Convert to PygtsObjects */
 	if (pygts_point_check(o_)) {
@@ -227,9 +219,7 @@ static PyObject* orientation_3d(PygtsPoint* self, PyObject* args)
 	SELF_CHECK
 
 	/* Parse the args */
-	if (!PyArg_ParseTuple(args, "OOO", &p1_, &p2_, &p3_)) {
-		return NULL;
-	}
+	if (!PyArg_ParseTuple(args, "OOO", &p1_, &p2_, &p3_)) { return NULL; }
 
 	/* Convert to PygtsObjects */
 	if (!pygts_point_check(p1_)) {
@@ -263,9 +253,7 @@ static PyObject* orientation_3d_sos(PygtsPoint* self, PyObject* args)
 	SELF_CHECK
 
 	/* Parse the args */
-	if (!PyArg_ParseTuple(args, "OOO", &p1_, &p2_, &p3_)) {
-		return NULL;
-	}
+	if (!PyArg_ParseTuple(args, "OOO", &p1_, &p2_, &p3_)) { return NULL; }
 
 	/* Convert to PygtsObjects */
 	if (!pygts_point_check(p1_)) {
@@ -301,9 +289,7 @@ static PyObject* is_in_circle(PygtsPoint* self, PyObject* args)
 	SELF_CHECK
 
 	/* Parse the args */
-	if (!PyArg_ParseTuple(args, "O|OO", &o1_, &o2_, &o3_)) {
-		return NULL;
-	}
+	if (!PyArg_ParseTuple(args, "O|OO", &o1_, &o2_, &o3_)) { return NULL; }
 	if ((o2_ == NULL && o3_ != NULL) || (o2_ != NULL && o3_ == NULL)) {
 		PyErr_SetString(PyExc_TypeError, "expected three Points or one Triangle");
 		return NULL;
@@ -341,10 +327,8 @@ static PyObject* is_in_circle(PygtsPoint* self, PyObject* args)
 		result = gts_point_in_circle(
 		        PYGTS_POINT_AS_GTS_POINT(self), PYGTS_POINT_AS_GTS_POINT(p1), PYGTS_POINT_AS_GTS_POINT(p2), PYGTS_POINT_AS_GTS_POINT(p3));
 	}
-	if (result > 0)
-		return Py_BuildValue("i", 1);
-	if (result == 0)
-		return Py_BuildValue("i", 0);
+	if (result > 0) return Py_BuildValue("i", 1);
+	if (result == 0) return Py_BuildValue("i", 0);
 	return Py_BuildValue("i", -1);
 }
 
@@ -357,9 +341,7 @@ static PyObject* is_in(PygtsPoint* self, PyObject* args)
 	SELF_CHECK
 
 	/* Parse the args */
-	if (!PyArg_ParseTuple(args, "O", &t_)) {
-		return NULL;
-	}
+	if (!PyArg_ParseTuple(args, "O", &t_)) { return NULL; }
 
 	/* Convert to PygtsObjects */
 	if (!pygts_triangle_check(t_)) {
@@ -382,9 +364,7 @@ static PyObject* is_inside(PygtsPoint* self, PyObject* args)
 	SELF_CHECK
 
 	/* Parse the args */
-	if (!PyArg_ParseTuple(args, "O", &s_)) {
-		return NULL;
-	}
+	if (!PyArg_ParseTuple(args, "O", &s_)) { return NULL; }
 
 	/* Convert to PygtsObjects */
 	if (!pygts_surface_check(s_)) {
@@ -402,9 +382,7 @@ static PyObject* is_inside(PygtsPoint* self, PyObject* args)
 	/* Determing is_open parameter; note the meaning is different from the 
    * error check above.
    */
-	if (gts_surface_volume(PYGTS_SURFACE_AS_GTS_SURFACE(s)) < 0.) {
-		is_open = TRUE;
-	}
+	if (gts_surface_volume(PYGTS_SURFACE_AS_GTS_SURFACE(s)) < 0.) { is_open = TRUE; }
 
 	/* Construct the tree */
 	if ((tree = gts_bb_tree_surface(PYGTS_SURFACE_AS_GTS_SURFACE(s))) == NULL) {
@@ -437,9 +415,7 @@ static PyObject* closest(PygtsPoint* self, PyObject* args)
 	SELF_CHECK
 
 	/* Parse the args */
-	if (!PyArg_ParseTuple(args, "OO", &o1_, &o2_)) {
-		return NULL;
-	}
+	if (!PyArg_ParseTuple(args, "OO", &o1_, &o2_)) { return NULL; }
 
 	/* Convert to PygtsObjects */
 	if (pygts_segment_check(o1_)) {
@@ -498,12 +474,9 @@ static PyObject* rotate(PygtsPoint* self, PyObject* args, PyObject* keywds)
 	SELF_CHECK
 
 	/* Parse the args */
-	if (!PyArg_ParseTupleAndKeywords(args, keywds, "|dddd", kwlist, &dx, &dy, &dz, &a)) {
-		return NULL;
-	}
+	if (!PyArg_ParseTupleAndKeywords(args, keywds, "|dddd", kwlist, &dx, &dy, &dz, &a)) { return NULL; }
 
-	if (pygts_point_rotate(PYGTS_POINT_AS_GTS_POINT(self), dx, dy, dz, a) == -1)
-		return NULL;
+	if (pygts_point_rotate(PYGTS_POINT_AS_GTS_POINT(self), dx, dy, dz, a) == -1) return NULL;
 
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -538,12 +511,9 @@ static PyObject* scale(PygtsPoint* self, PyObject* args, PyObject* keywds)
 	SELF_CHECK
 
 	/* Parse the args */
-	if (!PyArg_ParseTupleAndKeywords(args, keywds, "|ddd", kwlist, &dx, &dy, &dz)) {
-		return NULL;
-	}
+	if (!PyArg_ParseTupleAndKeywords(args, keywds, "|ddd", kwlist, &dx, &dy, &dz)) { return NULL; }
 
-	if (pygts_point_scale(PYGTS_POINT_AS_GTS_POINT(self), dx, dy, dz) == -1)
-		return NULL;
+	if (pygts_point_scale(PYGTS_POINT_AS_GTS_POINT(self), dx, dy, dz) == -1) return NULL;
 
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -578,12 +548,9 @@ static PyObject* translate(PygtsPoint* self, PyObject* args, PyObject* keywds)
 	SELF_CHECK
 
 	/* Parse the args */
-	if (!PyArg_ParseTupleAndKeywords(args, keywds, "|ddd", kwlist, &dx, &dy, &dz)) {
-		return NULL;
-	}
+	if (!PyArg_ParseTupleAndKeywords(args, keywds, "|ddd", kwlist, &dx, &dy, &dz)) { return NULL; }
 
-	if (pygts_point_translate(PYGTS_POINT_AS_GTS_POINT(self), dx, dy, dz) == -1)
-		return NULL;
+	if (pygts_point_translate(PYGTS_POINT_AS_GTS_POINT(self), dx, dy, dz) == -1) return NULL;
 
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -831,12 +798,8 @@ static PyObject* new_(PyTypeObject* type, PyObject* args, PyObject* kwds)
 	/* Parse the args */
 	if (kwds) {
 		o = PyDict_GetItemString(kwds, "alloc_gtsobj");
-		if (o == Py_False) {
-			alloc_gtsobj = FALSE;
-		}
-		if (o != NULL) {
-			PyDict_DelItemString(kwds, "alloc_gtsobj");
-		}
+		if (o == Py_False) { alloc_gtsobj = FALSE; }
+		if (o != NULL) { PyDict_DelItemString(kwds, "alloc_gtsobj"); }
 	}
 	if (kwds) {
 		Py_INCREF(Py_False);
@@ -872,17 +835,13 @@ static int init(PygtsPoint* self, PyObject* args, PyObject* kwds)
 	obj = PYGTS_OBJECT(self);
 
 	/* Parse the args */
-	if (!PyArg_ParseTupleAndKeywords(args, kwds, "|dddi", kwlist, &x, &y, &z, &a)) {
-		return -1;
-	}
+	if (!PyArg_ParseTupleAndKeywords(args, kwds, "|dddi", kwlist, &x, &y, &z, &a)) { return -1; }
 
 	/* Initialize */
 	gts_point_set(GTS_POINT(obj->gtsobj), x, y, z);
 
 	/* Chain up */
-	if ((ret = PygtsObjectType.tp_init((PyObject*)self, args, kwds)) != 0) {
-		return ret;
-	}
+	if ((ret = PygtsObjectType.tp_init((PyObject*)self, args, kwds)) != 0) { return ret; }
 
 	return 0;
 }
@@ -905,12 +864,10 @@ static int compare(PyObject* p1_, PyObject* p2_)
 #if PY_MAJOR_VERSION >= 3
 static PyObject* rich_compare(PyObject* o1, PyObject* o2, int op)
 {
-	if (o2 == Py_None)
-		Py_RETURN_FALSE; // comparing with nothing
+	if (o2 == Py_None) Py_RETURN_FALSE; // comparing with nothing
 	switch (op) {
 		case Py_EQ: {
-			if (compare(o1, o2))
-				Py_RETURN_TRUE;
+			if (compare(o1, o2)) Py_RETURN_TRUE;
 			Py_RETURN_FALSE;
 		}
 		default: Py_RETURN_NOTIMPLEMENTED;
@@ -979,9 +936,7 @@ gboolean pygts_point_check(PyObject* o)
 	PyObject* obj;
 
 	/* Check for a Point */
-	if (PyObject_TypeCheck(o, &PygtsPointType)) {
-		check = TRUE;
-	}
+	if (PyObject_TypeCheck(o, &PygtsPointType)) { check = TRUE; }
 
 	/* Convert list into tuple */
 	if (PyList_Check(o)) {
@@ -996,9 +951,7 @@ gboolean pygts_point_check(PyObject* o)
 			check = TRUE;
 			for (i = 0; i < N; i++) {
 				obj = PyTuple_GET_ITEM(o, i);
-				if (!PyFloat_Check(obj) && !PyLong_Check(obj)) {
-					check = FALSE;
-				}
+				if (!PyFloat_Check(obj) && !PyLong_Check(obj)) { check = FALSE; }
 			}
 		}
 	}
@@ -1008,9 +961,7 @@ gboolean pygts_point_check(PyObject* o)
 		return FALSE;
 	} else {
 #if PYGTS_DEBUG
-		if (PyObject_TypeCheck(o, &PygtsPointType)) {
-			return pygts_point_is_ok(PYGTS_POINT(o));
-		}
+		if (PyObject_TypeCheck(o, &PygtsPointType)) { return pygts_point_is_ok(PYGTS_POINT(o)); }
 #endif
 		return TRUE;
 	}
@@ -1086,20 +1037,17 @@ PygtsPoint* pygts_point_from_sequence(PyObject* tuple)
 			return NULL;
 		}
 		if (i == 0) {
-			if (PyFloat_Check(obj))
-				x = PyFloat_AsDouble(obj);
+			if (PyFloat_Check(obj)) x = PyFloat_AsDouble(obj);
 			else
 				x = (double)PyLong_AsLong(obj);
 		}
 		if (i == 1) {
-			if (PyFloat_Check(obj))
-				y = PyFloat_AsDouble(obj);
+			if (PyFloat_Check(obj)) y = PyFloat_AsDouble(obj);
 			else
 				y = (double)PyLong_AsLong(obj);
 		}
 		if (i == 2) {
-			if (PyFloat_Check(obj))
-				z = PyFloat_AsDouble(obj);
+			if (PyFloat_Check(obj)) z = PyFloat_AsDouble(obj);
 			else
 				z = (double)PyLong_AsLong(obj);
 		}
@@ -1107,9 +1055,7 @@ PygtsPoint* pygts_point_from_sequence(PyObject* tuple)
 	Py_DECREF(tuple);
 
 	/* Create the vertex */
-	if ((p = gts_point_new(gts_point_class(), x, y, z)) == NULL) {
-		PyErr_SetString(PyExc_MemoryError, "could not create Point");
-	}
+	if ((p = gts_point_new(gts_point_class(), x, y, z)) == NULL) { PyErr_SetString(PyExc_MemoryError, "could not create Point"); }
 	if ((point = pygts_point_new(p)) == NULL) {
 		gts_object_destroy(GTS_OBJECT(p));
 		return NULL;
@@ -1123,47 +1069,36 @@ int pygts_point_compare(GtsPoint* p1, GtsPoint* p2)
 {
 	double r1, r2;
 
-	if ((p1->x == p2->x) && (p1->y == p2->y) && (p1->z == p2->z)) {
-		return 0;
-	}
+	if ((p1->x == p2->x) && (p1->y == p2->y) && (p1->z == p2->z)) { return 0; }
 
 	/* Compare distances from origin */
 	r1 = sqrt(pow(p1->x, 2) + pow(p1->y, 2) + pow(p1->z, 2));
 	r2 = sqrt(pow(p2->x, 2) + pow(p2->y, 2) + pow(p2->z, 2));
-	if (r1 < r2)
-		return -1;
-	if (r1 > r2)
-		return 1;
+	if (r1 < r2) return -1;
+	if (r1 > r2) return 1;
 
 	/* Compare horizontal distances from origin */
 	r1 = sqrt(pow(p1->x, 2) + pow(p1->y, 2));
 	r2 = sqrt(pow(p2->x, 2) + pow(p2->y, 2));
-	if (r1 < r2)
-		return -1;
-	if (r1 > r2)
-		return 1;
+	if (r1 < r2) return -1;
+	if (r1 > r2) return 1;
 
 	/* Compare x */
 	r1 = p1->x;
 	r2 = p2->x;
-	if (r1 < r2)
-		return -1;
-	if (r1 > r2)
-		return 1;
+	if (r1 < r2) return -1;
+	if (r1 > r2) return 1;
 
 	/* Compare y */
 	r1 = p1->y;
 	r2 = p2->y;
-	if (r1 < r2)
-		return -1;
-	if (r1 > r2)
-		return 1;
+	if (r1 < r2) return -1;
+	if (r1 > r2) return 1;
 
 	/* Compare z */
 	r1 = p1->z;
 	r2 = p2->z;
-	if (r1 < r2)
-		return -1;
+	if (r1 < r2) return -1;
 	return 1;
 }
 
