@@ -23,6 +23,8 @@
 #include <core/Engine.hpp>
 #include <pkg/common/KinematicEngines.hpp>
 #include <pkg/common/MatchMaker.hpp>
+#include <pkg/dem/FrictPhys.hpp>
+#include <pkg/dem/ScGeom.hpp>
 #include <preprocessing/dem/SpherePack.hpp>
 #ifdef YADE_OPENGL
 #include <pkg/common/GLDrawFunctors.hpp>
@@ -87,7 +89,8 @@ struct custom_OpenMPAccumulator_to_float {
 #if (YADE_REAL_BIT <= 64)
 	static PyObject* convert(const OpenMPAccumulator<Real>& acc) { return boost::python::incref(PyFloat_FromDouble(acc.get())); }
 #else
-	static PyObject* convert(const OpenMPAccumulator<Real>& acc) { return ArbitraryReal_to_python<Real>::convert(acc.get()); }
+	// use RealVisitor here. Don't use slow python mpmath.
+	static PyObject* convert(const OpenMPAccumulator<Real>& acc) { return boost::python::incref(boost::python::object(acc.get()).ptr()); }
 #endif
 };
 struct custom_OpenMPAccumulator_from_float {
@@ -333,7 +336,7 @@ struct custom_mask_from_long {
 		new (storage) mask_t;
 		mask_t* mask = (mask_t*)storage;
 #if PY_MAJOR_VERSION >= 3
-		obj_ptr = _PyLong_Format(obj_ptr, 2);
+		obj_ptr = PyNumber_ToBase(obj_ptr, 2);
 		std::string s(PyUnicode_AsUTF8(obj_ptr));
 #else
 		obj_ptr = _PyLong_Format(obj_ptr, 2, 0, 0);
@@ -417,6 +420,8 @@ try {
 		VECTOR_SEQ_CONV(shared_ptr<LawFunctor>);
 		VECTOR_SEQ_CONV(shared_ptr<IntrCallback>);
 		VECTOR_SEQ_CONV(shared_ptr<Interaction>);
+		VECTOR_SEQ_CONV(shared_ptr<ScGeom>);    // MultiScGeom.contacts
+		VECTOR_SEQ_CONV(shared_ptr<FrictPhys>); // MultiFrictPhys.contacts
 #ifdef YADE_BODY_CALLBACK
 		VECTOR_SEQ_CONV(shared_ptr<BodyCallback>);
 #endif
