@@ -5,11 +5,20 @@
 PATHDEB="/home/anton/deb/"
 
 set -e
+
+# check, if $PATHDEB/OLD_ID exists and if not, create it
+if [ ! -f ${PATHDEB}/OLD_ID ]
+then
+	touch ${PATHDEB}/OLD_ID
+	echo "0" > ${PATHDEB}/OLD_ID
+fi
+
 OLD_ID=$(cat ${PATHDEB}/OLD_ID)
+
 NEW_ID=$(curl -L "https://gitlab.com/api/v4/projects/10133144/repository/commits/master" | jq --raw-output '.short_id')
 if [ "$OLD_ID" != "$NEW_ID" ]
 then
-	for i in bionic buster stretch xenial bullseye focal jammy bookworm trixie
+	for i in bionic bullseye focal jammy bookworm trixie noble
 	do
 		cd ${PATHDEB}
 		wget https://gitlab.com/api/v4/projects/10133144/jobs/artifacts/master/download?job=deb_$i -O yade.zip
